Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(70)

Unified Diff: chrome/browser/resources/options/autofill_options_list.js

Issue 1999923002: Move the Google Payments URL functions out of content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/common.gypi ('k') | chrome/browser/ui/startup/bad_flags_prompt.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/options/autofill_options_list.js
diff --git a/chrome/browser/resources/options/autofill_options_list.js b/chrome/browser/resources/options/autofill_options_list.js
index cd3dd261b6df6913bee591154350a168fe1d1030..723c44b551d75926fd069718bd9710d51172992c 100644
--- a/chrome/browser/resources/options/autofill_options_list.js
+++ b/chrome/browser/resources/options/autofill_options_list.js
@@ -98,14 +98,14 @@ cr.define('options.autofillOptions', function() {
/**
* For local Autofill data, this function causes the AutofillOptionsHandler
* to call showEditAddressOverlay(). For Wallet data, the user is
* redirected to the Wallet web interface.
*/
loadAddressEditor: function() {
if (this.metadata_.isLocal)
chrome.send('loadAddressEditor', [this.metadata_.guid]);
else
- window.open(loadTimeData.getString('manageWalletAddressesUrl'));
+ window.open(loadTimeData.getString('paymentsManageAddressesUrl'));
},
};
@@ -171,14 +171,14 @@ cr.define('options.autofillOptions', function() {
/**
* For local Autofill data, this function causes the AutofillOptionsHandler
* to call showEditCreditCardOverlay(). For Wallet data, the user is
* redirected to the Wallet web interface.
*/
loadCreditCardEditor: function() {
if (this.metadata_.isLocal)
chrome.send('loadCreditCardEditor', [this.metadata_.guid]);
else
- window.open(loadTimeData.getString('manageWalletPaymentMethodsUrl'));
+ window.open(loadTimeData.getString('paymentsManageInstrumentsUrl'));
},
};
« no previous file with comments | « build/common.gypi ('k') | chrome/browser/ui/startup/bad_flags_prompt.cc » ('j') | no next file with comments »
@@ -98,14 +98,14 @@ cr.define('options.autofillOptions', function() {
/**
* For local Autofill data, this function causes the AutofillOptionsHandler
- * to call showEditAddressOverlay(). For Wallet data, the user is
- * redirected to the Wallet web interface.
+ * to call showEditAddressOverlay(). For Payments data, the user is
+ * redirected to the Payments web interface.
*/
loadAddressEditor: function() {
@@ -171,14 +171,14 @@ cr.define('options.autofillOptions', function() {
/**
* For local Autofill data, this function causes the AutofillOptionsHandler
- * to call showEditCreditCardOverlay(). For Wallet data, the user is
- * redirected to the Wallet web interface.
+ * to call showEditCreditCardOverlay(). For Payments data, the user is
+ * redirected to the Payments web interface.
*/
loadCreditCardEditor: function() {

Powered by Google App Engine
This is Rietveld 408576698